#!/bin/bash
# $Revision: 1.16 $
# STANDARD 1.0
# PLUGIN TYPE:WEB

######################################################################
echo "BEGIN: $(basename $0) $*" >&2
######################################################################
# Questo e' un "bash script plugin" per BuDuScRiPt/budus_xdcc.sh

# Il suo scopo e' quello di fornire un "motore di ricerca" per il sito
# di XDCC "xdcc.it".

######################################################################
# Lo script "budus_xdcc.sh" invoca questo script passando, come primo
# parametro, un codice casuale che serve per calcolare il file dentro
# al quale immagazzinare il risultato opportunamente filtrato.
RANDOM_NUMBER=${1}

# Il secondo parametro e' il numero di secondi d'attesa del risultato
# dal sito web interrogato, trascorsi i quali, si deve interrompere la
# ricerca del plugin.
WGET_TIMEOUT=${2}

# Il terzo parametro rappresenta la "stringa di ricerca" immessa
# dall'utente.
SEARCH_STRING=${3}

######################################################################
# Il TIMEOUT degli XBSPSE di tipo WEB deve essere configurato ad un
# massimo di 32 secondi.
if [ ${WGET_TIMEOUT:-33} -gt 32 ]; then
    WGET_TIMEOUT=32
fi

######################################################################
# VARIABILI AD USO DEL FILTRO
######################################################################
db_url="http://xdcc.it"
query_string="/?q="
post_query_string=""
wget_option="-q -t 1 -O - -T ${WGET_TIMEOUT}"

######################################################################
# Viene calcolato il nome del file dati dentro al quale immagazzinare
# il risultato.
plugin_name=$(echo "${0}" | sed 's@.*budus_xdcc_plugin_@@' | cut -f1 -d'.')
user_home=$(echo "${HOME}" | tr [:punct:] '_')
plugin_tempfile=/tmp/budus_XDCC_${plugin_name}_${user_home}_${RANDOM_NUMBER}

######################################################################
# Codifica alcuni caratteri speciali
SEARCH_STRING=$(echo "${SEARCH_STRING}" \
    | sed 's@&@%2F@g' \
    | sed 's@%@%26@g' \
    | sed 's@\$@%24@g' \
    | sed 's@%@%25@g' \
    | sed 's@&@%2F@g' \
    | sed 's@,@%2C@g' \
    | sed 's@;@%3B@g' \
    | sed 's@:@%3A@g' \
    | sed 's@+@%2B@g' \
    | sed 's@ @+@g')

# Interroga il WEB Search Engine
wget ${wget_option} ${db_url}${query_string}"${SEARCH_STRING}"${post_query_string} | sed 's/\r//g' > ${plugin_tempfile}
cp -f ${plugin_tempfile} /tmp/budus_XDCC_db_${plugin_name}.dat

######################################################################
if [ ! -f "${plugin_tempfile}" ]; then
    echo > "${plugin_tempfile}"
    if [ ! -f "${plugin_tempfile}" ]; then
	echo "/ECHO %C4,1Non sono in grado di creare files temporanei in /tmp, problema di permessi ?"
	echo "/ECHO (${plugin_tempfile})"
	exit 1;
    else
	echo "/ECHO %C4,1Il plugin non e' stato in grado di generare il database. Segnalare il problema a UDA'Software, se persiste."
	exit 1;
    fi
fi

######################################################################
# Filtraggio
# L'output del filtro e' rappresentato da 8 campi separati dal
# carattere di tabulazione '\t', ovvero:
# NETWORK_NAME NETWORK_HOST CHANNEL BOT_NAME ID FILE_NAME SIZE COMMAND
#       1            2         3        4    5      6      7      8
######################################################################
cat ${plugin_tempfile} \
    | tr '\n' ' ' \
    | sed 's/onmouseover=/\n/g' \
    | sed 's@</tr>@\n@g' \
    | grep -F '"xdt(' \
    | sed 's@<[/]\?td>@\n@g' \
    | sed 's@<a.*</strong>[ ]\?@@' \
    | sed 's@</a>@@g' \
    | sed 's@"xdt('\''@XDCC_BUDUSCRIPT_DATA_RECORD:@g' \
    | sed 's@'\'',[ ]\?'\''@\n@g' \
    | sed 's@'\'');">@@g' \
    | sed 's/[ ]*$//g' \
    | tr '\n' '\t' \
    | sed 's/XDCC_BUDUSCRIPT_DATA_RECORD:/\n/g' \
    | sed 's@<a title=".*">@@g' \
    | grep -v '^$' \
    | sed 's@<br />@@g' \
    | awk -F'\t' '{print $4"\t"$6"\t"$3"\t"$2"\t"$5"\t"$1"\t"$11"\t/msg "$2" xdcc send #"$5"\n"}' \
    | sed 's@ xdcc send ##@ xdcc send #@' > ${plugin_tempfile}.database

######################################################################
rm -f ${plugin_tempfile}

######################################################################
echo "END  : $(basename $0) $*" >&2
######################################################################